[Xfce4-commits] r22663 - in thunar/trunk: . thunar

Benedikt Meurer benny at xfce.org
Fri Aug 4 22:17:50 UTC 2006


Author: benny
Date: 2006-08-04 22:17:48 +0000 (Fri, 04 Aug 2006)
New Revision: 22663

Modified:
   thunar/trunk/ChangeLog
   thunar/trunk/thunar/thunar-application.c
   thunar/trunk/thunar/thunar-path-entry.c
Log:
2006-08-05	Benedikt Meurer <benny at xfce.org>

	* thunar/thunar-application.c(thunar_application_unlink_files): Unlink
	  permanently if atleast one non-local (not necessary trash) file is
	  included in the file list.
	* thunar/thunar-path-entry.c(thunar_path_entry_changed): Do not try
	  to autocomplete non-local paths, as that's not going to work pro-
	  perly with trash paths anyway.




Modified: thunar/trunk/ChangeLog
===================================================================
--- thunar/trunk/ChangeLog	2006-08-04 22:17:10 UTC (rev 22662)
+++ thunar/trunk/ChangeLog	2006-08-04 22:17:48 UTC (rev 22663)
@@ -1,3 +1,12 @@
+2006-08-05	Benedikt Meurer <benny at xfce.org>
+
+	* thunar/thunar-application.c(thunar_application_unlink_files): Unlink
+	  permanently if atleast one non-local (not necessary trash) file is
+	  included in the file list.
+	* thunar/thunar-path-entry.c(thunar_path_entry_changed): Do not try
+	  to autocomplete non-local paths, as that's not going to work pro-
+	  perly with trash paths anyway.
+
 2006-08-04	Benedikt Meurer <benny at xfce.org>
 
 	* thunar/thunar-file.c(thunar_file_info_get_uri_scheme): Use a more

Modified: thunar/trunk/thunar/thunar-application.c
===================================================================
--- thunar/trunk/thunar/thunar-path-entry.c	2006-08-04 22:17:10 UTC (rev 22662)
+++ thunar/trunk/thunar/thunar-path-entry.c	2006-08-04 22:17:48 UTC (rev 22663)
@@ -809,17 +809,6 @@
     {
       /* try to parse the URI text */
       file_path = thunar_vfs_path_new (text, NULL);
-      if (G_LIKELY (file_path != NULL))
-        {
-          /* check if the file_path ends with a separator */
-          if (g_str_has_suffix (text, "/"))
-            folder_path = file_path;
-          else if (!thunar_vfs_path_is_root (file_path))
-            folder_path = thunar_vfs_path_get_parent (file_path);
-
-          /* need to take a reference for the folder_path */
-          thunar_vfs_path_ref (folder_path);
-        }
     }
   else if (thunar_path_entry_parse (path_entry, &folder_part, &file_part, NULL))
     {



More information about the Xfce4-commits mailing list
--- thunar/trunk/thunar/thunar-application.c	2006-08-04 22:17:10 UTC (rev 22662)
+++ thunar/trunk/thunar/thunar-application.c	2006-08-04 22:17:48 UTC (rev 22663)
@@ -1077,8 +1077,8 @@
       /* prepend the path to the path list */
       path_list = thunar_vfs_path_list_prepend (path_list, thunar_file_get_path (lp->data));
 
-      /* check if the file is in the trash already */
-      if (thunar_file_is_trashed (lp->data))
+      /* check if the file is not a local file */
+      if (!thunar_file_is_local (lp->data))
         permanently = TRUE;
     }
 

Modified: thunar/trunk/thunar/thunar-path-entry.c
===================================================================